andUI: AND module UI representation

View source: R/and.R

andUIR Documentation

AND module UI representation

Description

The AND module connects filtering and selection across multiple columns of a data.frame. Columns of class boolean, character or factor will be represented as textual ORs, numeric columns as numerical OR.

Usage

andUI(id)

Arguments

id

The ID of the modules namespace.

Value

A list with HTML tags from tag.


wilson documentation built on July 28, 2026, 5:07 p.m.