| colorPickerUI | R Documentation |
The functions creates HTML tag definitions of its representation based on the parameters supplied. Currently, two UI can be created for the user to choose either (a) colors from a given color scheme, or (b) choose one or more single colors.
colorPickerUI(
id,
label = "Color scheme",
custom = FALSE,
multiple = FALSE,
show.reverse = TRUE,
show.scaleoptions = TRUE,
show.transparency = TRUE
)
id |
The ID of the modules namespace. |
label |
Either a character vector of length one with the label for the color scheme dropdown, or a character vector containing labels of the single colors. |
custom |
Boolean if TRUE custom colors can be selected (Default = FALSE). |
multiple |
Boolean value, if set to TRUE custom colorpalettes can be made. Only if custom = TRUE (Default = FALSE). |
show.reverse |
Logical, whether or not to show the reverse switch (Default = TRUE). |
show.scaleoptions |
Logical, whether or not to show color scaling option winsorize (Default = TRUE). |
show.transparency |
Logical, whether or not to show the transparency slider (Default = TRUE). |
A list with HTML tags from tag.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.