columnSelectorUI: columnSelector module UI representation

View source: R/columnSelector.R

columnSelectorUIR Documentation

columnSelector module UI representation

Description

columnSelector module UI representation

Usage

columnSelectorUI(id, label = FALSE, title = NULL)

Arguments

id

The ID of the modules namespace.

label

Boolean value; if true include a text input field with the desired axis label (this should be preset with the headline of the column)

title

String which is displayed as module title. (Default = NULL)

Value

A list from tag with the UI elements.


wilson documentation built on July 28, 2026, 5:07 p.m.