| create_logger | R Documentation |
create a logger used within the package
create_logger(logfile = NULL, level = "INFO", name = "wilson")
logfile |
Path to a file log messages should be written to. NULL (default) logs to the console only. |
level |
Threshold level of the logger. Messages below this level are dropped. One of "TRACE", "DEBUG", "INFO", "WARN", "ERROR", "FATAL". |
name |
Name of the logger. |
Thin convenience wrapper around get_logger that sets the threshold and, optionally, attaches a file appender (AppenderFile). The returned object can be handed to set_logger.
An lgr Logger object.
logger <- create_logger(level = "INFO")
set_logger(logger, token = "example")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.