| download | R Documentation |
downloadHandler content function.Function used for downloading.
Creates a zip container containing plot in png, pdf and user input in json format.
Use inside downloadHandler content function.
download(
file,
filename,
plot,
width,
height,
ppi = 72,
save_plot = TRUE,
ui = NULL
)
file |
See |
filename |
See |
plot |
Plot to download. |
width |
in centimeter. |
height |
in centimeter. |
ppi |
pixel per inch. Defaults to 72. |
save_plot |
Logical if plot object should be saved as .RData. |
ui |
List of user inputs. Will be converted to JavaScript Object Notation. See |
Path to zip archive invisibly. See zipr.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.