Provides server logic for the geneView module.
geneView(
input,
output,
session,
clarion,
plot.method = "static",
label.sep = ", ",
width = "auto",
height = "auto",
ppi = 72,
scale = 1
)Reactive containing data.table used for plotting.
Shiny's input object.
Shiny's output object.
Shiny's session object.
A clarion object. See Clarion. (Supports reactive)
Choose which method is used for plotting. Either "static" or "interactive" (Default = "static").
Separator used for label merging (Default = ", ").
Width of the plot in cm. Defaults to minimal size for readable labels and supports reactive.
Height of the plot in cm. Defaults to minimal size for readable labels and supports reactive.
Pixel per inch. Defaults to 72 and supports reactive.
Scale plot size. Defaults to 1, supports reactive.
Width/ height/ ppi less or equal to default will use default value.
Ppi less or equal to zero will use default.