Learn R Programming

wilson (version 2.4.4)

transformation: transformation module server logic

Description

The module provides several transformations on a numeric data matrix for the user.

Usage

transformation(
  input,
  output,
  session,
  data,
  transpose = FALSE,
  pseudocount = 1,
  replaceInf = TRUE,
  replaceNA = TRUE
)

Value

Namedlist of two containing data and name of the used method. data: Reactive containing the transformed matrix. Infinite values are replaced by NA and NA values are replaced by 0. method: Reactive containing String. transpose: Reactive containing String.

Arguments

input

Shiny's input object.

output

Shiny's output object.

session

Shiny's session object.

data

Numeric matrix on which transformation is performed (column-wise). (Supports reactive)

transpose

Whether the matrix should be transposed to enable row-wise transformation. (Supports reactive)

pseudocount

Numeric Variable to add a pseudocount to log-based transformations. (Supports reactive)

replaceInf

Change Infinite to NA, applied after transformation. (Supports reactive)

replaceNA

Change NA to 0, applied after transformation. (Supports reactive)