Learn R Programming

wilson (version 2.4.4)

andUI: AND module UI representation

Description

The AND module connects filtering and selection across multiple columns of a data.frame. Columns of class boolean, character or factor will be represented as textual ORs, numeric columns as numerical OR.

Usage

andUI(id)

Value

A list with HTML tags from tag.

Arguments

id

The ID of the modules namespace.