The module provides several transformations on a numeric data matrix for the user.
transformation(
input,
output,
session,
data,
transpose = FALSE,
pseudocount = 1,
replaceInf = TRUE,
replaceNA = TRUE
)Namedlist of two containing data and name of the used method. data: Reactive containing the transformed matrix. Infinite values are replaced by NA and NA values are replaced by 0. method: Reactive containing String. transpose: Reactive containing String.
Shiny's input object.
Shiny's output object.
Shiny's session object.
Numeric matrix on which transformation is performed (column-wise). (Supports reactive)
Whether the matrix should be transposed to enable row-wise transformation. (Supports reactive)
Numeric Variable to add a pseudocount to log-based transformations. (Supports reactive)
Change Infinite to NA, applied after transformation. (Supports reactive)
Change NA to 0, applied after transformation. (Supports reactive)